]> granicus.if.org Git - neomutt/commitdiff
doxy: doc config items
authorRichard Russon <rich@flatcap.org>
Sun, 5 Aug 2018 21:56:42 +0000 (22:56 +0100)
committerRichard Russon <rich@flatcap.org>
Mon, 6 Aug 2018 09:50:05 +0000 (10:50 +0100)
21 files changed:
commands.c
config/address.c
config/bool.c
config/long.c
config/magic.c
config/mbtable.c
config/number.c
config/path.c
config/quad.c
config/regex.c
config/sort.c
config/string.c
curs_main.c
globals.h
ncrypt/crypt.c
ncrypt/cryptglue.c
ncrypt/pgp.c
ncrypt/smime.c
notmuch/mutt_notmuch.c
send.c
sort.h

index 579d1b59556fa31f7120be35acd15dd0adf47e3c..3cc63a96867d232b7ca9ed1612c4db896d73dcd5 100644 (file)
@@ -69,7 +69,7 @@
 #endif
 
 /* These Config Variables are only used in commands.c */
-unsigned char CryptVerifySig; /* verify PGP signatures */
+unsigned char CryptVerifySig; /* verify PGP signatures */ ///< Config: Verify PGP or SMIME signatures
 char *DisplayFilter; ///< Config: External command to pre-process an email before display
 bool PipeDecode;  ///< Config: Decode the message when piping it
 char *PipeSep;    ///< Config: Separator to add between multiple piped messages
index 019218b0cd86418c7335b4a815ab6c42be82ef3d..2477fff847c855d258345e522e04deee8e7a6cae 100644 (file)
@@ -202,7 +202,7 @@ static intptr_t address_native_get(const struct ConfigSet *cs, void *var,
 }
 
 /**
- * address_reset - Reset an Address to its initial value - Implements ::cst_regex
+ * address_reset - Reset an Address to its initial value - Implements ::cst_reset
  */
 static int address_reset(const struct ConfigSet *cs, void *var,
                          const struct ConfigDef *cdef, struct Buffer *err)
index fe0975da56008c57630b2769523ef889fc983ebf..fe8e1eeff5be03d55137a010747fdd0a3a1e10b4 100644 (file)
@@ -165,7 +165,7 @@ static intptr_t bool_native_get(const struct ConfigSet *cs, void *var,
 }
 
 /**
- * bool_reset - Reset a Bool to its initial value - Implements ::cst_regex
+ * bool_reset - Reset a Bool to its initial value - Implements ::cst_reset
  */
 static int bool_reset(const struct ConfigSet *cs, void *var,
                       const struct ConfigDef *cdef, struct Buffer *err)
index 27f713afb8109e2ccf6304e00cb062c8a7bc1445..33ae350a6b117149118b1837023b5f7f92bd388e 100644 (file)
@@ -143,7 +143,7 @@ static intptr_t long_native_get(const struct ConfigSet *cs, void *var,
 }
 
 /**
- * long_reset - Reset a Long to its initial value - Implements ::cst_regex
+ * long_reset - Reset a Long to its initial value - Implements ::cst_reset
  */
 static int long_reset(const struct ConfigSet *cs, void *var,
                       const struct ConfigDef *cdef, struct Buffer *err)
index 2e1651bfcece90c29fa5d74952720187b6d2caf3..85c5176c7ac05d1e4c9e1f2604c9e3cd7c896e66 100644 (file)
@@ -167,7 +167,7 @@ static intptr_t magic_native_get(const struct ConfigSet *cs, void *var,
 }
 
 /**
- * magic_reset - Reset a Mailbox Magic to its initial value - Implements ::cst_regex
+ * magic_reset - Reset a Mailbox Magic to its initial value - Implements ::cst_reset
  */
 static int magic_reset(const struct ConfigSet *cs, void *var,
                        const struct ConfigDef *cdef, struct Buffer *err)
index b48dba9b48bd9fcec02fba52cf37db5ab7f54c2c..7641bb431b0e328777b29d275748da419d6677a8 100644 (file)
@@ -244,7 +244,7 @@ static intptr_t mbtable_native_get(const struct ConfigSet *cs, void *var,
 }
 
 /**
- * mbtable_reset - Reset an MbTable to its initial value - Implements ::cst_regex
+ * mbtable_reset - Reset an MbTable to its initial value - Implements ::cst_reset
  */
 static int mbtable_reset(const struct ConfigSet *cs, void *var,
                          const struct ConfigDef *cdef, struct Buffer *err)
index 81a598cce0ded63bef3b4734fcf0fc75f5ed250c..3de938cf24a41abc606672740bde082ed0975c5e 100644 (file)
@@ -162,7 +162,7 @@ static intptr_t number_native_get(const struct ConfigSet *cs, void *var,
 }
 
 /**
- * number_reset - Reset a Number to its initial value - Implements ::cst_regex
+ * number_reset - Reset a Number to its initial value - Implements ::cst_reset
  */
 static int number_reset(const struct ConfigSet *cs, void *var,
                         const struct ConfigDef *cdef, struct Buffer *err)
index 10976b178d46a2687fbdd192f28e4fa9b1cee98e..0ef48f78ff8971044d9c33f24d50048121cfaefd 100644 (file)
@@ -199,7 +199,7 @@ static intptr_t path_native_get(const struct ConfigSet *cs, void *var,
 }
 
 /**
- * path_reset - Reset a Path to its initial value - Implements ::cst_regex
+ * path_reset - Reset a Path to its initial value - Implements ::cst_reset
  */
 static int path_reset(const struct ConfigSet *cs, void *var,
                       const struct ConfigDef *cdef, struct Buffer *err)
index 5bbf8c5151a15ea7f29b98fb574989ecd865a6ad..aa43cbc064b9f7fda33f7d672e03fa037703a9bf 100644 (file)
@@ -164,7 +164,7 @@ static intptr_t quad_native_get(const struct ConfigSet *cs, void *var,
 }
 
 /**
- * quad_reset - Reset a Quad-option to its initial value - Implements ::cst_regex
+ * quad_reset - Reset a Quad-option to its initial value - Implements ::cst_reset
  */
 static int quad_reset(const struct ConfigSet *cs, void *var,
                       const struct ConfigDef *cdef, struct Buffer *err)
index 3f761b321337286bf553d05635b4c94d8078f6d7..6e8915a3a90b7b0c20f9100f2df26bf51ea4b129 100644 (file)
@@ -204,7 +204,7 @@ static intptr_t regex_native_get(const struct ConfigSet *cs, void *var,
 }
 
 /**
- * regex_reset - Reset a Regex to its initial value - Implements ::cst_regex
+ * regex_reset - Reset a Regex to its initial value - Implements ::cst_reset
  */
 static int regex_reset(const struct ConfigSet *cs, void *var,
                        const struct ConfigDef *cdef, struct Buffer *err)
index ced454d10a314e870842b11d3bf1ebf4019f47fb..0d16e4e9865bb40fde348cb890c197c7ad36bc8a 100644 (file)
@@ -351,7 +351,7 @@ static intptr_t sort_native_get(const struct ConfigSet *cs, void *var,
 }
 
 /**
- * sort_reset - Reset a Sort to its initial value - Implements ::cst_regex
+ * sort_reset - Reset a Sort to its initial value - Implements ::cst_reset
  */
 static int sort_reset(const struct ConfigSet *cs, void *var,
                       const struct ConfigDef *cdef, struct Buffer *err)
index 4a44d7ced5d14441ec51aadde79332b3c1f5d317..9019866ac6f46122a3e9bde5a9879280760c160a 100644 (file)
@@ -200,7 +200,7 @@ static intptr_t string_native_get(const struct ConfigSet *cs, void *var,
 }
 
 /**
- * string_reset - Reset a String to its initial value - Implements ::cst_regex
+ * string_reset - Reset a String to its initial value - Implements ::cst_reset
  */
 static int string_reset(const struct ConfigSet *cs, void *var,
                         const struct ConfigDef *cdef, struct Buffer *err)
index 9a56ce8c859507de282b498628671d453eaabd4f..e5be2c4976786027ee349f71f5b10bd685870723 100644 (file)
@@ -92,7 +92,7 @@ bool CollapseAll; ///< Config: Collapse all threads when entering a folder
 bool CollapseFlagged; ///< Config: Prevent the collapse of threads with flagged emails
 bool CollapseUnread; ///< Config: Prevent the collapse of threads with unread emails
 char *MarkMacroPrefix;
-bool PgpAutoDecode;
+bool PgpAutoDecode; ///< Config: Automatically decrypt PGP messages
 bool UncollapseJump; ///< Config: When opening a thread, jump to the next unread message
 bool UncollapseNew; ///< Config: Open collapsed threads when new mail arrives
 
index 09a77863351ffb3405d77e3525a945f930338313..ad114c744eed14956414a04c7c755e2c10d3b293 100644 (file)
diff --git a/send.c b/send.c
index 36abcb74587bee9a305a51967d40a1edc385b4fe..0032499c1b937445e5066ae07be32d9c16d16d8f 100644 (file)
--- a/send.c
+++ b/send.c
@@ -78,13 +78,13 @@ unsigned char AbortUnmodified;
 bool AskFollowUp; ///< Config: (nntp) Ask the user for follow-up groups before editing
 bool AskXCommentTo; ///< Config: (nntp) Ask the user for the 'X-Comment-To' field before editing
 char *ContentType; ///< Config: Default "Content-Type" for newly composed messages
-bool CryptAutoencrypt;
-bool CryptAutopgp;
-bool CryptAutosign;
-bool CryptAutosmime;
-bool CryptReplyencrypt;
-bool CryptReplysign;
-bool CryptReplysignencrypted;
+bool CryptAutoencrypt; ///< Config: Automatically PGP encrypt all outgoing mail
+bool CryptAutopgp; ///< Config: Allow automatic PGP functions
+bool CryptAutosign; ///< Config: Automatically PGP sign all outgoing mail
+bool CryptAutosmime; ///< Config: Allow automatic SMIME functions
+bool CryptReplyencrypt; ///< Config: Encrypt replies to encrypted messages
+bool CryptReplysign; ///< Config: Sign replies to signed messages
+bool CryptReplysignencrypted; ///< Config: Sign replies to encrypted messages
 char *EmptySubject; ///< Config: Subject to use when replying to an email with none
 bool FastReply; ///< Config: Don't prompt for the recipients and subject when replying/forwarding
 unsigned char FccAttach; ///< Config: Save send message with all their attachments
@@ -101,7 +101,7 @@ bool IgnoreListReplyTo;
 unsigned char Include; ///< Config: Include a copy of the email that's being replied to
 bool Metoo;
 bool NmRecord;
-bool PgpReplyinline;
+bool PgpReplyinline; ///< Config: Reply using old-style inline PGP messages (not recommended)
 char *PostIndentString;
 bool PostponeEncrypt; ///< Config: Self-encrypt postponed messages
 char *PostponeEncryptAs; ///< Config: Fallback encryption key for postponed messages
diff --git a/sort.h b/sort.h
index f5838cc60e11c239f9fcfc2dced12005fb6b44fe..e6edd7b8861ec81ce3245760474d5d8dce7a65de 100644 (file)
--- a/sort.h
+++ b/sort.h
@@ -60,6 +60,6 @@ WHERE short Sort;  ///< Config: Sort method for the index
 WHERE short SortAux; /* auxiliary sorting method */  ///< Config: Secondary sort method for the index
 
 /* FIXME: This one does not belong to here */
-WHERE short PgpSortKeys;
+WHERE short PgpSortKeys; ///< Config: Sort order for PGP keys
 
 #endif /* _MUTT_SORT_H */
--- a/globals.h
+++ b/globals.h
@@ -167,14 +167,14 @@ WHERE short ImapPollTimeout;
 #endif
 
 /* -- formerly in pgp.h -- */
-WHERE char *PgpDefaultKey;
-WHERE char *PgpSignAs;
+WHERE char *PgpDefaultKey; ///< Config: Default key to use for PGP operations
+WHERE char *PgpSignAs; ///< Config: Use this alternative key for signing messages
 WHERE char *PgpEntryFormat; ///< Config: printf-like format string for the PGP key selection menu
 
 /* -- formerly in smime.h -- */
-WHERE char *SmimeDefaultKey;
-WHERE char *SmimeSignAs;
-WHERE char *SmimeEncryptWith;
+WHERE char *SmimeDefaultKey; ///< Config: Default key for SMIME operations
+WHERE char *SmimeSignAs; ///< Config: Use this alternative key for signing messages
+WHERE char *SmimeEncryptWith; ///< Config: Algorithm for encryption
 
 #ifdef USE_NOTMUCH
 WHERE int NmQueryWindowDuration;
@@ -265,17 +265,17 @@ WHERE bool WaitKey;  ///< Config: Prompt to press a key after running external c
 WHERE bool WrapSearch;
 WHERE bool WriteBcc; /**< write out a bcc header? */
 
-WHERE bool CryptUsePka;
+WHERE bool CryptUsePka; ///< Config: Use GPGME to use PKA (lookup PGP keys using DNS)
 
 /* PGP options */
 
-WHERE bool CryptConfirmhook;
-WHERE bool CryptOpportunisticEncrypt;
-WHERE bool SmimeIsDefault;
-WHERE bool PgpIgnoreSubkeys;
-WHERE bool PgpLongIds;
-WHERE bool PgpShowUnusable;
-WHERE bool PgpAutoinline;
+WHERE bool CryptConfirmhook; ///< Config: Prompt the user to confirm keys before use
+WHERE bool CryptOpportunisticEncrypt; ///< Config: Enable encryption when the recipient's key is available
+WHERE bool SmimeIsDefault; ///< Config: Use SMIME rather than PGP by default
+WHERE bool PgpIgnoreSubkeys; ///< Config: Only use the principal PGP key
+WHERE bool PgpLongIds; ///< Config: Display long PGP key IDs to the user
+WHERE bool PgpShowUnusable; ///< Config: Show non-usable keys in the key selection
+WHERE bool PgpAutoinline; ///< Config: Use old-style inline PGP messages (not recommended)
 
 /* news options */
 
index 38b4ff3a921b0f1b4fc3d786454b2f3f6d1a2520..53eb354830aaede64a7044538784ca3f47a058ae 100644 (file)
 #include "state.h"
 
 /* These Config Variables are only used in ncrypt/crypt.c */
-bool CryptTimestamp;
+bool CryptTimestamp; ///< Config: Add a timestamp to PGP or SMIME output to prevent spoofing
 unsigned char PgpEncryptSelf;
-unsigned char PgpMimeAuto; /* ask to revert to PGP/MIME when inline fails */
-bool PgpRetainableSigs;
-bool PgpSelfEncrypt;
-bool PgpStrictEnc;
+unsigned char PgpMimeAuto; /* ask to revert to PGP/MIME when inline fails */ ///< Config: Prompt the user to use MIME if inline PGP fails
+bool PgpRetainableSigs; ///< Config: Create nested multipart/signed or encrypted messages
+bool PgpSelfEncrypt; ///< Config: Encrypted messages will also be encrypted to PgpDefaultKey too
+bool PgpStrictEnc; ///< Config: Encode PGP signed messages with quoted-printable (don't unset)
 unsigned char SmimeEncryptSelf;
-bool SmimeSelfEncrypt;
+bool SmimeSelfEncrypt; ///< Config: Encrypted messages will also be encrypt to SmimeDefaultKey too
 
 /**
  * crypt_current_time - Print the current time
index b627de140a5d283843aa832f24aabb11a82eb50f..aa3ad8851b90d3b1607fd6db22ddb0c997167543 100644 (file)
@@ -50,7 +50,7 @@ struct Header;
 struct State;
 
 /* These Config Variables are only used in ncrypt/cryptglue.c */
-bool CryptUseGpgme;
+bool CryptUseGpgme; ///< Config: Use GPGME crypto backend
 
 #ifdef CRYPT_BACKEND_CLASSIC_PGP
 extern struct CryptModuleSpecs crypt_mod_pgp_classic;
index 047b7298f95ef4e44b8e8111ff002c3283c3e529..27c7044260266746d08544974afe5b4c2ec855a8 100644 (file)
 #include "state.h"
 
 /* These Config Variables are only used in ncrypt/pgp.c */
-bool PgpCheckExit;
-bool PgpCheckGpgDecryptStatusFd;
-struct Regex *PgpDecryptionOkay;
-struct Regex *PgpGoodSign;
-long PgpTimeout;
-bool PgpUseGpgAgent;
+bool PgpCheckExit; ///< Config: Check the exit code of PGP subprocess
+bool PgpCheckGpgDecryptStatusFd; ///< Config: File descriptor used for status info
+struct Regex *PgpDecryptionOkay; ///< Config: Text indicating a successful decryption
+struct Regex *PgpGoodSign; ///< Config: Text indicating a good signature
+long PgpTimeout; ///< Config: Time in seconds to cache a passphrase
+bool PgpUseGpgAgent; ///< Config: Use a PGP agent for caching passwords
 
 char PgpPass[LONG_STRING];
 time_t PgpExptime = 0; /* when does the cached passphrase expire? */
index 3881e5a93e66c04bb0afd86ec233c848a0694d27..a999c4073f59d331c116882e30d6310ad2e48b2d 100644 (file)
 #include "state.h"
 
 /* These Config Variables are only used in ncrypt/smime.c */
-bool SmimeAskCertLabel;
-char *SmimeCaLocation;
-char *SmimeCertificates;
+bool SmimeAskCertLabel; ///< Config: Prompt the user for a label for SMIME certificates
+char *SmimeCaLocation;   ///< Config: File containing trusted certificates
+char *SmimeCertificates; ///< Config: File containing user's public certificates
 char *SmimeDecryptCommand; ///< Config: (smime) External command to decrypt an SMIME message
-bool SmimeDecryptUseDefaultKey;
+bool SmimeDecryptUseDefaultKey; ///< Config: Use the default key for decryption
 char *SmimeEncryptCommand; ///< Config: (smime) External command to encrypt a message
 char *SmimeGetCertCommand; ///< Config: (smime) External command to extract a certificate from a message
 char *SmimeGetCertEmailCommand; ///< Config: (smime) External command to get a certificate for an email
 char *SmimeGetSignerCertCommand; ///< Config: (smime) External command to extract a certificate from an email
 char *SmimeImportCertCommand; ///< Config: (smime) External command to import a certificate
-char *SmimeKeys;
+char *SmimeKeys; ///< Config: File containing user's private certificates
 char *SmimePk7outCommand; ///< Config: (smime) External command to extract a public certificate
 char *SmimeSignCommand; ///< Config: (smime) External command to sign a message
-char *SmimeSignDigestAlg;
-long SmimeTimeout;
+char *SmimeSignDigestAlg; ///< Config: Digest algorithm
+long SmimeTimeout;        ///< Config: Time in seconds to cache a passphrase
 char *SmimeVerifyCommand; ///< Config: (smime) External command to verify a signed message
 char *SmimeVerifyOpaqueCommand; ///< Config: (smime) External command to verify a signature
 
index cc1b55ad0da0dcc4b10682adf4b6519821a21139..c408c4b957fa04af2a1b05111acdfeb3b820ef8c 100644 (file)
@@ -2287,7 +2287,7 @@ char *nm_get_description(struct Context *ctx)
 }
 
 /**
- * nm_desc&ription_to_path - Find a path from a folder's description
+ * nm_description_to_path - Find a path from a folder's description
  * @param desc   Description
  * @param buf    Buffer for path
  * @param buflen Length of buffer